@@ -124,7 +124,7 @@ class Pool:
         try:
             aiomysql = importlib.import_module("aiomysql")
         except ImportError:
-            raise Exception(f"pymysql is not exist,run:pip install aiomysql")
+            raise Exception(f"aiomysql is not exist,run:pip install aiomysql")
         pool = await aiomysql.create_pool(host=conn_info.host, port=conn_info.port,
                                           user=conn_info.user,
                                           password=conn_info.password,
@@ -159,6 +159,227 @@ class Pool:
                                   read_timeout=30)
         return pool
 
+    @staticmethod
+    async def create_sqlite3_pool(conn_info: ConnectionInfo):
+        """
+        创建mysql 异步连接池
+        :param conn_info: 连接信息
+        :return:
+        """
+        try:
+            aiosqlite3 = importlib.import_module("aiosqlite3")
+        except ImportError:
+            raise Exception(f"aiosqlite3 is not exist,run:pip install aiosqlite3")
+        pool = await aiosqlite3.connect(database=conn_info.dsn)
+        return pool
+
+    @staticmethod
+    def sync_create_sqlite3_pool(conn_info: ConnectionInfo):
+        """
+        创建mysql 同步连接池
+        :param conn_info: 连接信息
+        :return:
+        """
+        try:
+            sqlite3 = importlib.import_module("sqlite3")
+        except ImportError:
+            raise Exception(f"sqlite3 is not exist,run:pip install sqlite3")
+        try:
+            pooled_db = importlib.import_module("dbutils.pooled_db")
+        except ImportError:
+            raise Exception(f"DBUtils is not exist,run:pip install DBUtils")
+        pool = pooled_db.PooledDB(creator=sqlite3, host=conn_info.host, port=conn_info.port,
+                                  user=conn_info.user,
+                                  passwd=conn_info.password, db=conn_info.db_name,
+                                  mincached=conn_info.min_size, blocking=True, maxusage=conn_info.min_size,
+                                  maxshared=conn_info.max_size, maxcached=conn_info.max_size,
+                                  ping=1, maxconnections=conn_info.max_size, charset="utf8mb4", autocommit=True,
+                                  read_timeout=30)
+        return pool
+
+    @staticmethod
+    def sync_create_mssql_pool(conn_info: ConnectionInfo):
+        """
+        创建mysql 同步连接池
+        :param conn_info: 连接信息
+        :return:
+        """
+        try:
+            pymssql = importlib.import_module("pymssql")
+        except ImportError:
+            raise Exception(f"pymssql is not exist,run:pip install pymssql")
+        try:
+            pooled_db = importlib.import_module("dbutils.pooled_db")
+        except ImportError:
+            raise Exception(f"DBUtils is not exist,run:pip install DBUtils")
+        pool = pooled_db.PooledDB(creator=pymssql, host=conn_info.host, port=conn_info.port,
+                                  user=conn_info.user,
+                                  passwd=conn_info.password, db=conn_info.db_name,
+                                  mincached=conn_info.min_size, blocking=True, maxusage=conn_info.min_size,
+                                  maxshared=conn_info.max_size, maxcached=conn_info.max_size,
+                                  ping=1, maxconnections=conn_info.max_size, charset="utf8mb4", autocommit=True,
+                                  read_timeout=30)
+        return pool
+
+    @staticmethod
+    def sync_create_oracle_pool(conn_info: ConnectionInfo):
+        """
+        创建mysql 同步连接池
+        :param conn_info: 连接信息
+        :return:
+        """
+        try:
+            cx_oracle = importlib.import_module("cx_Oracle")
+        except ImportError:
+            raise Exception(f"cx_Oracle is not exist,run:pip install cx_Oracle")
+        try:
+            pooled_db = importlib.import_module("dbutils.pooled_db")
+        except ImportError:
+            raise Exception(f"DBUtils is not exist,run:pip install DBUtils")
+        pool = pooled_db.PooledDB(creator=cx_oracle, host=conn_info.host, port=conn_info.port,
+                                  user=conn_info.user,
+                                  passwd=conn_info.password, db=conn_info.db_name,
+                                  mincached=conn_info.min_size, blocking=True, maxusage=conn_info.min_size,
+                                  maxshared=conn_info.max_size, maxcached=conn_info.max_size,
+                                  ping=1, maxconnections=conn_info.max_size, charset="utf8mb4", autocommit=True,
+                                  read_timeout=30)
+        return pool
+
+    @staticmethod
+    async def create_doris_pool(conn_info: ConnectionInfo):
+        """
+        创建doris 异步连接池
+        :param conn_info: 连接信息
+        :return:
+        """
+        try:
+            aiomysql = importlib.import_module("aiomysql")
+        except ImportError:
+            raise Exception(f"aiomysql is not exist,run:pip install aiomysql")
+        pool = await aiomysql.create_pool(host=conn_info.host, port=conn_info.port,
+                                          user=conn_info.user,
+                                          password=conn_info.password,
+                                          pool_recycle=conn_info.params.get("pool_recycle", 3600)
+                                          if conn_info.params else 3600,
+                                          db=conn_info.db_name, autocommit=True,
+                                          minsize=conn_info.min_size,
+                                          maxsize=conn_info.max_size)
+        return pool
+
+    @staticmethod
+    def sync_create_doris_pool(conn_info: ConnectionInfo):
+        """
+        创建doris 同步连接池
+        :param conn_info: 连接信息
+        :return:
+        """
+        try:
+            pymysql = importlib.import_module("pymysql")
+        except ImportError:
+            raise Exception(f"pymysql is not exist,run:pip install pymysql")
+        try:
+            pooled_db = importlib.import_module("dbutils.pooled_db")
+        except ImportError:
+            raise Exception(f"DBUtils is not exist,run:pip install DBUtils")
+        pool = pooled_db.PooledDB(creator=pymysql, host=conn_info.host, port=conn_info.port,
+                                  user=conn_info.user,
+                                  passwd=conn_info.password, db=conn_info.db_name,
+                                  mincached=conn_info.min_size, blocking=True, maxusage=conn_info.min_size,
+                                  maxshared=conn_info.max_size, maxcached=conn_info.max_size,
+                                  ping=1, maxconnections=conn_info.max_size, charset="utf8mb4", autocommit=True,
+                                  read_timeout=30)
+        return pool
+
+    @staticmethod
+    async def create_tidb_pool(conn_info: ConnectionInfo):
+        """
+        创建tidb 异步连接池
+        :param conn_info: 连接信息
+        :return:
+        """
+        try:
+            aiomysql = importlib.import_module("aiomysql")
+        except ImportError:
+            raise Exception(f"aiomysql is not exist,run:pip install aiomysql")
+        pool = await aiomysql.create_pool(host=conn_info.host, port=conn_info.port,
+                                          user=conn_info.user,
+                                          password=conn_info.password,
+                                          pool_recycle=conn_info.params.get("pool_recycle", 3600)
+                                          if conn_info.params else 3600,
+                                          db=conn_info.db_name, autocommit=True,
+                                          minsize=conn_info.min_size,
+                                          maxsize=conn_info.max_size)
+        return pool
+
+    @staticmethod
+    def sync_create_tidb_pool(conn_info: ConnectionInfo):
+        """
+        创建tidb 同步连接池
+        :param conn_info: 连接信息
+        :return:
+        """
+        try:
+            pymysql = importlib.import_module("pymysql")
+        except ImportError:
+            raise Exception(f"pymysql is not exist,run:pip install pymysql")
+        try:
+            pooled_db = importlib.import_module("dbutils.pooled_db")
+        except ImportError:
+            raise Exception(f"DBUtils is not exist,run:pip install DBUtils")
+        pool = pooled_db.PooledDB(creator=pymysql, host=conn_info.host, port=conn_info.port,
+                                  user=conn_info.user,
+                                  passwd=conn_info.password, db=conn_info.db_name,
+                                  mincached=conn_info.min_size, blocking=True, maxusage=conn_info.min_size,
+                                  maxshared=conn_info.max_size, maxcached=conn_info.max_size,
+                                  ping=1, maxconnections=conn_info.max_size, charset="utf8mb4", autocommit=True,
+                                  read_timeout=30)
+        return pool
+
+    @staticmethod
+    async def create_ocean_base_pool(conn_info: ConnectionInfo):
+        """
+        创建ocean_base 异步连接池
+        :param conn_info: 连接信息
+        :return:
+        """
+        try:
+            aiomysql = importlib.import_module("aiomysql")
+        except ImportError:
+            raise Exception(f"aiomysql is not exist,run:pip install aiomysql")
+        pool = await aiomysql.create_pool(host=conn_info.host, port=conn_info.port,
+                                          user=conn_info.user,
+                                          password=conn_info.password,
+                                          pool_recycle=conn_info.params.get("pool_recycle", 3600)
+                                          if conn_info.params else 3600,
+                                          db=conn_info.db_name, autocommit=True,
+                                          minsize=conn_info.min_size,
+                                          maxsize=conn_info.max_size)
+        return pool
+
+    @staticmethod
+    def sync_create_ocean_base_pool(conn_info: ConnectionInfo):
+        """
+        创建ocean_base 同步连接池
+        :param conn_info: 连接信息
+        :return:
+        """
+        try:
+            pymysql = importlib.import_module("pymysql")
+        except ImportError:
+            raise Exception(f"pymysql is not exist,run:pip install pymysql")
+        try:
+            pooled_db = importlib.import_module("dbutils.pooled_db")
+        except ImportError:
+            raise Exception(f"DBUtils is not exist,run:pip install DBUtils")
+        pool = pooled_db.PooledDB(creator=pymysql, host=conn_info.host, port=conn_info.port,
+                                  user=conn_info.user,
+                                  passwd=conn_info.password, db=conn_info.db_name,
+                                  mincached=conn_info.min_size, blocking=True, maxusage=conn_info.min_size,
+                                  maxshared=conn_info.max_size, maxcached=conn_info.max_size,
+                                  ping=1, maxconnections=conn_info.max_size, charset="utf8mb4", autocommit=True,
+                                  read_timeout=30)
+        return pool
+
     @staticmethod
     def sync_create_nebula_pool(conn_info: ConnectionInfo):
         """
@@ -427,6 +648,10 @@ class Pool:
                 url = 'mysql+aiomysql://{}:{}@{}:{}/{}?charset=utf8mb4'.format(
                     conn_info.user, conn_info.password, conn_info.host, conn_info.port,
                     conn_info.db_name)
+            elif db_type == "doris":
+                url = 'mysql+aiomysql://{}:{}@{}:{}/{}?charset=utf8mb4'.format(
+                    conn_info.user, conn_info.password, conn_info.host, conn_info.port,
+                    conn_info.db_name)
             else:
                 raise Exception("UNSUPPORTED DB TYPE")
         try:
@@ -476,6 +701,20 @@ class Pool:
                 url = 'mysql+pymysql://{}:{}@{}:{}/{}?charset=utf8mb4'.format(
                     conn_info.user, conn_info.password, conn_info.host, conn_info.port,
                     conn_info.db_name)
+            elif db_type == "doris":
+                url = 'mysql+pymysql://{}:{}@{}:{}/{}?charset=utf8mb4'.format(
+                    conn_info.user, conn_info.password, conn_info.host, conn_info.port,
+                    conn_info.db_name)
+            elif db_type == "sqlite3":
+                url = conn_info.dsn
+            elif db_type == "mssql":
+                url = "mssql+pymssql://{}:{}@{}:{}/{}?charset=utf8mb4".format(
+                    conn_info.user, conn_info.password, conn_info.host, conn_info.port,
+                    conn_info.db_name)
+            elif db_type == "oracle":
+                url = "oracle+cx_oracle://{}:{}@{}:{}/{}?charset=utf8mb4".format(
+                    conn_info.user, conn_info.password, conn_info.host, conn_info.port,
+                    conn_info.db_name)
             else:
                 raise Exception("UNSUPPORTED DB TYPE")
         try:
@@ -525,6 +764,30 @@ def get_pool(conn_info: ConnectionInfo):
         else:
             return run_sync(Pool.sync_create_mysql_pool(conn_info))
 
+    elif conn_info.dialect == "doris":
+        if conn_info.async_enable:
+            return run_sync(Pool.create_doris_pool(conn_info))
+        else:
+            return run_sync(Pool.sync_create_doris_pool(conn_info))
+
+    elif conn_info.dialect == "ocean_base":
+        if conn_info.async_enable:
+            return run_sync(Pool.create_ocean_base_pool(conn_info))
+        else:
+            return run_sync(Pool.sync_create_ocean_base_pool(conn_info))
+
+    elif conn_info.dialect == "tidb":
+        if conn_info.async_enable:
+            return run_sync(Pool.create_tidb_pool(conn_info))
+        else:
+            return run_sync(Pool.sync_create_tidb_pool(conn_info))
+
+    elif conn_info.dialect == "mssql":
+        return run_sync(Pool.sync_create_mssql_pool(conn_info))
+
+    elif conn_info.dialect == "oracle":
+        return run_sync(Pool.sync_create_oracle_pool(conn_info))
+
     elif conn_info.dialect == "nebula":
         return run_sync(Pool.sync_create_nebula_pool(conn_info))
 
@@ -540,6 +803,12 @@ def get_pool(conn_info: ConnectionInfo):
         else:
             return run_sync(Pool.sync_create_postgresql_pool(conn_info))
 
+    elif conn_info.dialect == "sqlite3":
+        if conn_info.async_enable:
+            return run_sync(Pool.create_sqlite3_pool(conn_info))
+        else:
+            return run_sync(Pool.sync_create_sqlite3_pool(conn_info))
+
     elif conn_info.dialect == "redis":
         if conn_info.async_enable:
             return run_sync(Pool.create_redis_pool(conn_info))
